package extensions

import (
	"context"
	"encoding/json"
	"fmt"
	"net/http"

	"github.com/google/go-querystring/query"
	"go.fifitido.net/twitch/api/endpoint"
)

type GetExtensionBitsProductsParams struct {
	// A Boolean value that determines whether to include disabled or expired Bits products in the response. The default is false.
	ShouldIncludeAll *bool `url:"should_include_all,omitempty"`
}

type GetExtensionBitsProductsResponse struct {
	// A list that contains the specified Bits products.
	Data []BitsProduct `json:"data"`
}

// Gets the list of Bits products that belongs to the extension. The client ID in the app access token identifies the extension.
//
// Requires an app access token. The client ID in the app access token must be the extension’s client ID.
func (e *Extensions) GetExtensionBitsProducts(ctx context.Context, params *GetExtensionBitsProductsParams) (*GetExtensionBitsProductsResponse, error) {
	v, _ := query.Values(params)

	req, err := http.NewRequestWithContext(ctx, http.MethodGet, endpoint.Make(e.baseUrl, "bits/extensions", v), nil)
	if err != nil {
		return nil, err
	}

	res, err := e.client.Do(req)
	if err != nil {
		return nil, err
	}
	defer res.Body.Close()

	statusOK := res.StatusCode >= 200 && res.StatusCode < 300
	if !statusOK {
		return nil, fmt.Errorf("failed to get extension bits products (%d)", res.StatusCode)
	}

	var data GetExtensionBitsProductsResponse
	if err := json.NewDecoder(res.Body).Decode(&data); err != nil {
		return nil, err
	}

	return &data, nil
}
