package extensions

import (
	"context"
	"encoding/json"
	"fmt"
	"net/http"

	"github.com/google/go-querystring/query"
	"go.fifitido.net/twitch/api/endpoint"
)

type GetReleasedExtensionsParams struct {
	// The ID of the extension to get.
	ExtensionID string `url:"extension_id"`

	// The version of the extension to get. If not specified, it returns the latest, released version.
	ExtensionVersion *string `url:"extension_version,omitempty"`
}

type GetReleasedExtensionsResponse struct {
	// A list that contains the specified extension.
	Data []Extension `json:"data"`
}

// Gets information about a released extension. Returns the extension if its state is Released.
//
// Requires an app access token or user access token.
func (e *Extensions) GetReleasedExtensions(ctx context.Context, params *GetReleasedExtensionsParams) (*GetReleasedExtensionsResponse, error) {
	v, _ := query.Values(params)

	req, err := http.NewRequestWithContext(ctx, http.MethodGet, endpoint.Make(e.baseUrl, "extensions/released", v), nil)
	if err != nil {
		return nil, err
	}

	res, err := e.client.Do(req)
	if err != nil {
		return nil, err
	}
	defer res.Body.Close()

	statusOK := res.StatusCode >= 200 && res.StatusCode < 300
	if !statusOK {
		return nil, fmt.Errorf("failed to get released extensions (%d)", res.StatusCode)
	}

	var data GetReleasedExtensionsResponse
	if err := json.NewDecoder(res.Body).Decode(&data); err != nil {
		return nil, err
	}

	return &data, nil
}
