package eventsub

import (
	"context"

	"go.fifitido.net/twitch/api"
	"go.fifitido.net/twitch/api/eventsub"
)

type EventSub struct {
	api       *api.API
	transport Transport

	subscriptions map[string]*eventsub.Subscription
}

func New(api *api.API, trans Transport) *EventSub {
	return &EventSub{
		api:       api,
		transport: trans,
	}
}

func (e *EventSub) Subscribe(ctx context.Context, subType eventsub.SubscriptionType, cond eventsub.Condition) error {
	res, err := e.api.EventSub.CreateEventSubSubscription(ctx, &eventsub.CreateEventSubSubscriptionRequest{
		SubscriptionType: subType,
		Condition:        cond,
		Transport:        e.transport.ApiTransport(),
	})

	if err != nil {
		return err
	}

	for _, sub := range res.Data {
		e.subscriptions[sub.ID] = sub
	}

	return nil
}

func (e *EventSub) Unsubscribe(ctx context.Context, subType eventsub.SubscriptionType) error {
	for _, sub := range e.subscriptions {
		if sub.SubType() == subType {
			if err := e.api.EventSub.DeleteEventSubSubscription(ctx, sub.ID); err != nil {
				return err
			}
		}
	}

	return nil
}

func (e *EventSub) Run() error {
	return e.transport.Run()
}

func (e *EventSub) Start() {
	e.transport.Start()
}

func (e *EventSub) Close() error {
	for _, sub := range e.subscriptions {
		if err := e.api.EventSub.DeleteEventSubSubscription(context.Background(), sub.ID); err != nil {
			return err
		}
	}

	if err := e.transport.Close(); err != nil {
		return err
	}

	return nil
}
